@@ -1,6 +1,5 @@
 import os
 import sys
-import random
 import traceback
 import json
 import functools
@@ -58,7 +57,7 @@ def do_work_wrapper(func, system_kwargs, user_kwargs, psets):
 
         if 'out_subdirs' in system_kwargs:
             # the entire pset group gets the same out_subdir
-            system_kwargs['out_subdir'] = 'ray'+str(random.randint(0, system_kwargs['out_subdirs'])).zfill(5)
+            system_kwargs['out_subdir'] = utils.make_subdir_name(system_kwargs['out_subdirs'])
 
         # multiprocesing workers start with parent's PWD so this probably won't get used
         if 'chdir' in system_kwargs:
@@ -138,6 +137,6 @@ def map(func, psets, out_func=None, user_kwargs=None, chdir=None, outfile=None,
     utils.finalize_progress(system_kwargs)
     utils.report_progress(system_kwargs, final=True)
 
-    system_stats.print_histograms(name)
+    system_stats.print_percentiles(name)
 
     return MapResults(system_kwargs['results'], list(system_kwargs['pset_ids'].values()), system_kwargs['progress'], system_stats)
